@@ -22,29 +22,26 @@
 
 #include "filteractionwithstringlist.h"
 
-namespace MailCommon
-{
-
+namespace MailCommon {
 //=============================================================================
 // FilterActionRemoveHeader - remove header
 // Remove all instances of the given header field.
 //=============================================================================
-class FilterActionRemoveHeader: public FilterActionWithStringList
+class FilterActionRemoveHeader : public FilterActionWithStringList
 {
     Q_OBJECT
 public:
     explicit FilterActionRemoveHeader(QObject *parent = nullptr);
-    ReturnCode process(ItemContext &context, bool applyOnOutbound) const Q_DECL_OVERRIDE;
-    SearchRule::RequiredPart requiredPart() const Q_DECL_OVERRIDE;
-    QWidget *createParamWidget(QWidget *parent) const Q_DECL_OVERRIDE;
-    void setParamWidgetValue(QWidget *paramWidget) const Q_DECL_OVERRIDE;
-    QStringList sieveRequires() const Q_DECL_OVERRIDE;
-    QString sieveCode() const Q_DECL_OVERRIDE;
+    ReturnCode process(ItemContext &context, bool applyOnOutbound) const override;
+    SearchRule::RequiredPart requiredPart() const override;
+    QWidget *createParamWidget(QWidget *parent) const override;
+    void setParamWidgetValue(QWidget *paramWidget) const override;
+    QStringList sieveRequires() const override;
+    QString sieveCode() const override;
 
     static FilterAction *newAction();
-    QString informationAboutNotValidAction() const Q_DECL_OVERRIDE;
+    QString informationAboutNotValidAction() const override;
 };
-
 }
 
 #endif
