@@ -103,14 +103,6 @@ const char _wt_filterlist_rename[]
                 "naming back, click this button and select <em>Clear</em> followed "
                 "by <em>OK</em> in the appearing dialog.</p></qt>");
 
-const char _wt_filterdlg_showLater[]
-    = I18N_NOOP("<qt><p>Check this button to force the confirmation dialog to be "
-                "displayed.</p><p>This is useful if you have defined a ruleset that tags "
-                "messages to be downloaded later. Without the possibility to force "
-                "the dialog popup, these messages could never be downloaded if no "
-                "other large messages were waiting on the server, or if you wanted to "
-                "change the ruleset to tag the messages differently.</p></qt>");
-
 //=============================================================================
 //
 // class KMFilterListBox (the filter list manipulator)
@@ -412,22 +404,15 @@ QList<MailFilter *> KMFilterListBox::filtersForSaving(bool closeAfterSaving, boo
 
     // report on invalid filters:
     if (!emptyFilters.empty()) {
-        if (closeAfterSaving) {
-            QPointer<MailCommon::InvalidFilterDialog> dlg = new MailCommon::InvalidFilterDialog(nullptr);
-            dlg->setInvalidFilters(listInvalidFilters);
-            if (!dlg->exec()) {
+        QPointer<MailCommon::InvalidFilterDialog> dlg = new MailCommon::InvalidFilterDialog(nullptr);
+        dlg->setInvalidFilters(listInvalidFilters);
+        if (!dlg->exec()) {
+            if (closeAfterSaving) {
                 Q_EMIT abortClosing();
-                wasCanceled = true;
             }
-            delete dlg;
-        } else {
-            QPointer<MailCommon::InvalidFilterDialog> dlg = new MailCommon::InvalidFilterDialog(nullptr);
-            dlg->setInvalidFilters(listInvalidFilters);
-            if (!dlg->exec()) {
-                wasCanceled = true;
-            }
-            delete dlg;
+            wasCanceled = true;
         }
+        delete dlg;
     }
     return filters;
 }
@@ -435,7 +420,7 @@ QList<MailFilter *> KMFilterListBox::filtersForSaving(bool closeAfterSaving, boo
 void KMFilterListBox::slotSelectionChanged()
 {
     if (mListWidget->selectedItems().count() > 1) {
-        resetWidgets();
+        Q_EMIT resetWidgets();
     }
     enableControls();
 }
@@ -612,11 +597,14 @@ QStringList KMFilterListBox::selectedFilterId(SearchRule::RequiredPart &required
     const int numberOfFilters = mListWidget->count();
     for (int i = 0; i < numberOfFilters; ++i) {
         if (mListWidget->item(i)->isSelected() && !mListWidget->item(i)->isHidden()) {
-            const QString id
-                = static_cast<QListWidgetFilterItem *>(mListWidget->item(i))->filter()->identifier();
-            listFilterId << id;
-            requiredPart = qMax(requiredPart,
-                                static_cast<QListWidgetFilterItem *>(mListWidget->item(i))->filter()->requiredPart(resource));
+            MailFilter *filter = static_cast<QListWidgetFilterItem *>(mListWidget->item(i))->filter();
+            if (!filter->isEmpty()) {
+                const QString id
+                        = filter->identifier();
+                listFilterId << id;
+                requiredPart = qMax(requiredPart,
+                                    static_cast<QListWidgetFilterItem *>(mListWidget->item(i))->filter()->requiredPart(resource));
+            }
         }
     }
     return listFilterId;
