@@ -41,6 +41,7 @@ using MailCommon::FilterLog;
 #include <kconfig.h>
 #include <kconfiggroup.h>
 #include <krandom.h>
+#include <QPointer>
 
 #include <algorithm>
 #include <boost/bind.hpp>
@@ -54,6 +55,7 @@ MailFilter::MailFilter()
     bApplyBeforeOutbound = false;
     bApplyOnOutbound = false;
     bApplyOnExplicit = true;
+    bApplyOnAllFolders = false;
     bStopProcessingHere = true;
     bConfigureShortcut = false;
     bConfigureToolbar = false;
@@ -76,6 +78,7 @@ MailFilter::MailFilter(const MailFilter &aFilter)
     bApplyBeforeOutbound = aFilter.applyBeforeOutbound();
     bApplyOnOutbound = aFilter.applyOnOutbound();
     bApplyOnExplicit = aFilter.applyOnExplicit();
+    bApplyOnAllFolders = aFilter.applyOnAllFoldersInbound();
     bStopProcessingHere = aFilter.stopProcessingHere();
     bConfigureShortcut = aFilter.configureShortcut();
     bConfigureToolbar = aFilter.configureToolbar();
@@ -236,6 +239,16 @@ bool MailFilter::applyOnExplicit() const
     return bApplyOnExplicit;
 }
 
+void MailFilter::setApplyOnAllFoldersInbound(bool aApply)
+{
+    bApplyOnAllFolders = aApply;
+}
+
+bool MailFilter::applyOnAllFoldersInbound() const
+{
+    return bApplyOnAllFolders;
+}
+
 void MailFilter::setApplicability(AccountType aApply)
 {
     mApplicability = aApply;
@@ -402,12 +415,14 @@ bool MailFilter::readConfig(const KConfigGroup &config, bool interactive)
         bApplyOnOutbound = false;
         bApplyOnInbound = true;
         bApplyOnExplicit = true;
+        bApplyOnAllFolders = false;
         mApplicability = ButImap;
     } else {
         bApplyBeforeOutbound = bool(sets.contains(QStringLiteral("before-send-mail")));
         bApplyOnInbound = bool(sets.contains(QStringLiteral("check-mail")));
         bApplyOnOutbound = bool(sets.contains(QStringLiteral("send-mail")));
         bApplyOnExplicit = bool(sets.contains(QStringLiteral("manual-filtering")));
+        bApplyOnAllFolders = bool(sets.contains(QStringLiteral("all-folders")));
         mApplicability = (AccountType)config.readEntry(
             "Applicability", (int)ButImap);
     }
@@ -474,7 +489,7 @@ bool MailFilter::readConfig(const KConfigGroup &config, bool interactive)
     mAccounts = config.readEntry("accounts-set", QStringList());
     if (!mAccounts.isEmpty() && interactive) {
         if (!MailCommon::FilterActionMissingAccountDialog::allAccountExist(mAccounts)) {
-            MailCommon::FilterActionMissingAccountDialog *dlg = new MailCommon::FilterActionMissingAccountDialog(mAccounts, name());
+            QPointer<MailCommon::FilterActionMissingAccountDialog> dlg = new MailCommon::FilterActionMissingAccountDialog(mAccounts, name());
             if (dlg->exec()) {
                 mAccounts = dlg->selectedAccount();
                 needUpdate = true;
@@ -492,6 +507,9 @@ void MailFilter::generateSieveScript(QStringList &requires, QString &code)
     QList<FilterAction *>::const_iterator it;
     QList<FilterAction *>::const_iterator end(mActions.constEnd());
 
+    const QString indentationStr{
+        QStringLiteral("    ")
+    };
     code += QLatin1String(")\n{\n");
     bool firstAction = true;
     for (it = mActions.constBegin(); it != end; ++it) {
@@ -501,7 +519,7 @@ void MailFilter::generateSieveScript(QStringList &requires, QString &code)
         } else {
             code += QLatin1Char('\n');
         }
-        code += QLatin1String("    ") + (*it)->sieveCode();
+        code += indentationStr + (*it)->sieveCode();
         const QStringList lstRequires = (*it)->sieveRequires();
         for (const QString &str : lstRequires) {
             if (!requires.contains(str)) {
@@ -509,6 +527,9 @@ void MailFilter::generateSieveScript(QStringList &requires, QString &code)
             }
         }
     }
+    if (bStopProcessingHere) {
+        code += QLatin1Char('\n') + indentationStr + QStringLiteral("stop;");
+    }
     code += QLatin1String("\n}\n");
 }
 
@@ -530,6 +551,9 @@ void MailFilter::writeConfig(KConfigGroup &config, bool exportFilter) const
     if (bApplyOnExplicit) {
         sets.append(QStringLiteral("manual-filtering"));
     }
+    if (bApplyOnAllFolders) {
+        sets.append(QStringLiteral("all-folders"));
+    }
     config.writeEntry("apply-on", sets);
 
     config.writeEntry("StopProcessingHere", bStopProcessingHere);
@@ -567,17 +591,24 @@ QString MailFilter::purify(bool removeAction)
 {
     QString informationAboutNotValidAction = mPattern.purify(removeAction);
 
-    QListIterator<FilterAction *> it(mActions);
-    it.toBack();
-    while (it.hasPrevious()) {
-        FilterAction *action = it.previous();
-        if (action->isEmpty()) {
-            if (!informationAboutNotValidAction.isEmpty()) {
-                informationAboutNotValidAction += QLatin1Char('\n');
-            }
-            informationAboutNotValidAction += action->informationAboutNotValidAction();
-            if (removeAction) {
-                mActions.removeAll(action);
+    if (mActions.isEmpty()) {
+        if (!informationAboutNotValidAction.isEmpty()) {
+            informationAboutNotValidAction += QLatin1Char('\n');
+        }
+        informationAboutNotValidAction += i18n("Any action defined.");
+    } else {
+        QListIterator<FilterAction *> it(mActions);
+        it.toBack();
+        while (it.hasPrevious()) {
+            FilterAction *action = it.previous();
+            if (action->isEmpty()) {
+                if (!informationAboutNotValidAction.isEmpty()) {
+                    informationAboutNotValidAction += QLatin1Char('\n');
+                }
+                informationAboutNotValidAction += action->informationAboutNotValidAction();
+                if (removeAction) {
+                    mActions.removeAll(action);
+                }
             }
         }
     }
@@ -623,46 +654,48 @@ const QString MailFilter::asString() const
     QList<FilterAction *>::const_iterator it(mActions.constBegin());
     QList<FilterAction *>::const_iterator end(mActions.constEnd());
     for (; it != end; ++it) {
-        result += "    action: ";
+        result += QStringLiteral("    action: ");
         result += (*it)->label();
-        result += ' ';
+        result += QLatin1Char(' ');
         result += (*it)->argsAsString();
-        result += '\n';
+        result += QLatin1Char('\n');
     }
-    result += "This filter belongs to the following sets:";
+    result += QStringLiteral("This filter belongs to the following sets:");
     if (bApplyOnInbound) {
-        result += " Inbound";
+        result += QStringLiteral(" Inbound");
     }
     if (bApplyBeforeOutbound) {
-        result += " before-Outbound";
+        result += QStringLiteral(" before-Outbound");
     }
     if (bApplyOnOutbound) {
-        result += " Outbound";
+        result += QStringLiteral(" Outbound");
     }
     if (bApplyOnExplicit) {
-        result += " Explicit";
+        result += QStringLiteral(" Explicit");
     }
-    result += '\n';
+    if (bApplyOnAllFolders) {
+        result += QStringLiteral(" All Folders");
+    }
+    result += QLatin1Char('\n');
     if (bApplyOnInbound && mApplicability == All) {
-        result += "This filter applies to all accounts.\n";
+        result += QStringLiteral("This filter applies to all accounts.\n");
     } else if (bApplyOnInbound && mApplicability == ButImap) {
-        result += "This filter applies to all but IMAP accounts.\n";
+        result += QStringLiteral("This filter applies to all but IMAP accounts.\n");
     } else if (bApplyOnInbound) {
-        QStringList::ConstIterator it2;
-        result += "This filter applies to the following accounts:";
+        result += QStringLiteral("This filter applies to the following accounts:");
         if (mAccounts.isEmpty()) {
-            result += " None";
+            result += QStringLiteral(" None");
         } else {
-            for (it2 = mAccounts.begin(); it2 != mAccounts.end(); ++it2) {
+            for (QStringList::ConstIterator it2 = mAccounts.begin(), it2End = mAccounts.end(); it2 != it2End; ++it2) {
                 if (Akonadi::AgentManager::self()->instance(*it2).isValid()) {
-                    result += ' ' + Akonadi::AgentManager::self()->instance(*it2).name();
+                    result += QLatin1Char(' ') + Akonadi::AgentManager::self()->instance(*it2).name();
                 }
             }
         }
-        result += '\n';
+        result += QLatin1Char('\n');
     }
     if (bStopProcessingHere) {
-        result += "If it matches, processing stops at this filter.\n";
+        result += QStringLiteral("If it matches, processing stops at this filter.\n");
     }
 
     return result;
@@ -689,6 +722,7 @@ QDataStream &MailCommon::operator<<(QDataStream &stream, const MailCommon::MailF
     stream << filter.bApplyBeforeOutbound;
     stream << filter.bApplyOnOutbound;
     stream << filter.bApplyOnExplicit;
+    stream << filter.bApplyOnAllFolders;
     stream << filter.bStopProcessingHere;
     stream << filter.bConfigureShortcut;
     stream << filter.bConfigureToolbar;
@@ -708,6 +742,7 @@ QDataStream &MailCommon::operator>>(QDataStream &stream, MailCommon::MailFilter
     bool bApplyBeforeOutbound;
     bool bApplyOnOutbound;
     bool bApplyOnExplicit;
+    bool bApplyOnAllFolders;
     bool bStopProcessingHere;
     bool bConfigureShortcut;
     bool bConfigureToolbar;
@@ -747,6 +782,7 @@ QDataStream &MailCommon::operator>>(QDataStream &stream, MailCommon::MailFilter
     stream >> bApplyBeforeOutbound;
     stream >> bApplyOnOutbound;
     stream >> bApplyOnExplicit;
+    stream >> bApplyOnAllFolders;
     stream >> bStopProcessingHere;
     stream >> bConfigureShortcut;
     stream >> bConfigureToolbar;
@@ -760,6 +796,7 @@ QDataStream &MailCommon::operator>>(QDataStream &stream, MailCommon::MailFilter
     filter.bApplyBeforeOutbound = bApplyBeforeOutbound;
     filter.bApplyOnOutbound = bApplyOnOutbound;
     filter.bApplyOnExplicit = bApplyOnExplicit;
+    filter.bApplyOnAllFolders = bApplyOnAllFolders;
     filter.bStopProcessingHere = bStopProcessingHere;
     filter.bConfigureShortcut = bConfigureShortcut;
     filter.bConfigureToolbar = bConfigureToolbar;
