@@ -34,7 +34,6 @@
 
 #include <CollectionFetchJob>
 
-#include <QDialog>
 #include <KIconLoader>
 #include <KLineEdit>
 #include <KLocalizedString>
@@ -43,7 +42,6 @@
 #include <QHBoxLayout>
 #include <QKeyEvent>
 #include <QToolButton>
-#include <KConfigGroup>
 
 namespace MailCommon {
 class FolderRequesterPrivate
@@ -58,10 +56,10 @@ public:
     }
 
     Akonadi::Collection mCollection;
-    KLineEdit *mEdit;
-    bool mMustBeReadWrite;
-    bool mShowOutbox;
-    bool mNotCreateNewFolder;
+    KLineEdit *mEdit = nullptr;
+    bool mMustBeReadWrite = false;
+    bool mShowOutbox = false;
+    bool mNotCreateNewFolder = false;
 };
 
 FolderRequester::FolderRequester(QWidget *parent)
@@ -157,6 +155,7 @@ void FolderRequester::slotCollectionsReceived(KJob *job)
     if (job->error()) {
         d->mCollection = Akonadi::Collection();
         d->mEdit->setText(i18n("Please select a folder"));
+        Q_EMIT invalidFolder();
         return;
     }
 
@@ -174,6 +173,7 @@ void FolderRequester::slotCollectionsReceived(KJob *job)
         // the requested collection doesn't exists anymore
         d->mCollection = Akonadi::Collection();
         d->mEdit->setText(i18n("Please select a folder"));
+        Q_EMIT invalidFolder();
     }
 }
 
